#
# spec file for package groff
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "full"
%define name_ext -full
%bcond_without full_build
%else
%define name_ext %nil
%bcond_with full_build
%endif
Name:           groff%{name_ext}
Version:        1.23.0
Release:        3.3
Summary:        GNU troff Document Formatting System
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/Troff
URL:            http://www.gnu.org/software/groff/groff.html
Source0:        ftp://ftp.gnu.org/gnu/groff/groff-%{version}.tar.gz
Source1:        ftp://ftp.gnu.org/gnu/groff/groff-%{version}.tar.gz.sig
Source2:        groff.keyring
Source3:        zzz-groff.sh
Source4:        zzz-groff.csh
Patch0:         groff-1.20.1-nroff-empty-LANGUAGE.patch
Patch1:         groff-1.20.1-deunicode.patch
Patch2:         groff-1.21-CVE-2009-5044.patch
# http://cvsweb.openwall.com/cgi/cvsweb.cgi/Owl/packages/groff/groff-1.20.1-owl-tmp.diff?rev=1.2;content-type=text%2Fplain
Patch3:         groff-1.21-CVE-2009-5081.patch
# PATCH-FIX-OPENSUSE: FATE#312586
#  sent upstream http://lists.gnu.org/archive/html/bug-groff/2011-09/msg00002.html
Patch4:         0001-locale-support-in-papersize-definition.patch
Patch5:         0002-documentation-for-the-locale-keyword.patch
# change the papersize definition to force the locale usage
# it can be supressed by /etc/papersize if needed
Patch6:         groff-force-locale-usage.patch
Patch7:         0004-don-t-use-usr-bin-env-in-shebang.patch
# PATCH-FIX-OPENSUSE groff-restore-hyphen-minus.patch bsc#1226153
Patch8:         groff-restore-hyphen-minus.patch
# Patches from debian
Patch100:       https://salsa.debian.org/debian/groff/raw/master/debian/patches/bash-scripts.patch
Patch101:       https://salsa.debian.org/debian/groff/raw/master/debian/patches/nroff-map-CW-to-R.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
%if %{with full_build}
BuildRequires:  ghostscript-library
BuildRequires:  groff
BuildRequires:  netpbm
BuildRequires:  psutils
BuildRequires:  pkgconfig(uchardet)
# for gxditview and X fontx
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xt)
Requires:       ghostscript-library
# ghostscript-library pulls in X and stuff anyways, so let's
# piggyback on that one
Supplements:    packageand(groff:ghostscript-library)
# requires the -base package
Requires:       groff = %{version}
Requires:       netpbm
Requires:       psutils
Requires(post): %{install_info_prereq}
Provides:       jgroff = %{version}-%{release}
Provides:       normal-groff = %{version}-%{release}
Obsoletes:      jgroff < %{version}
# X fonts were moved back
Provides:       groff-devx = %{version}-%{release}
Obsoletes:      groff-devx <= 1.21
# alternatives
BuildRequires:  update-alternatives
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif

%description
The groff package is a stripped-down package containing the necessary
components to read manual pages in ASCII, Latin-1, and UTF-8, plus the
PostScript device (groff's default).

%package -n groff-doc
Summary:        HTML documentation and examples for groff
Group:          Productivity/Publishing/Troff
BuildArch:      noarch

%description -n groff-doc
The groff package provides compatible versions of troff, nroff, eqn,
tbl, and other Unix text formatting utilities.

Groff is used to "compile" man pages stored in groff or nroff format
for different output devices, for example, displaying to a screen or in
PostScript format for printing on a PostScript printer.

%package -n gxditview
Summary:        Ditroff Output Displayer for Groff
Group:          Productivity/Publishing/Troff
Requires:       groff-full = %{version}
# bnc#668254
Supplements:    packageand(groff:xorg-x11-libX11)
Conflicts:      jgxdview
Provides:       gxdview = %{version}-%{release}
Obsoletes:      gxdview < %{version}

%description -n gxditview
This version of xditview is called gxditview and has some extensions
used by the groff command.  gxditview is used by groff if called with
the -X option.

%prep
%setup -q -n groff-%{version}
%autopatch -p1

# remove hardcoded docdir
sed -i \
    -e '/^docdir=/d' \
    Makefile.am

%build
autoreconf -fvi
# libdir redefined as it is just bunch of perl scripts
%configure \
    --disable-silent-rules \
    --docdir=%{_defaultdocdir}/groff \
    --libdir=%{_libexecdir} \
    --with-appdefdir=%{_datadir}/X11/app-defaults \
    --with-grofferdir=%{_libexecdir}/groff/groffer
make %{?_smp_mflags}

%install
%make_install

%if %{with full_build}
# remove groff basic files from bellow
rm -f %{buildroot}%{_sysconfdir}/profile.d/zzz-groff.csh
rm -f %{buildroot}%{_sysconfdir}/profile.d/zzz-groff.sh
rm -f %{buildroot}%{_bindir}/eqn
rm -f %{buildroot}%{_bindir}/groff
rm -f %{buildroot}%{_bindir}/grog
rm -f %{buildroot}%{_bindir}/grops
rm -f %{buildroot}%{_bindir}/grotty
rm -f %{buildroot}%{_bindir}/mmroff
rm -f %{buildroot}%{_bindir}/neqn
rm -f %{buildroot}%{_bindir}/nroff
rm -f %{buildroot}%{_bindir}/pic
rm -f %{buildroot}%{_bindir}/preconv
rm -f %{buildroot}%{_bindir}/soelim
rm -f %{buildroot}%{_bindir}/tbl
rm -f %{buildroot}%{_bindir}/troff
rm -f %{buildroot}%{_libexecdir}/groff/grog/subs.pl
rm -f %{buildroot}%{_datadir}/groff/current
rm -f %{buildroot}%{_datadir}/groff/1.23.0/eign
rm -rf %{buildroot}%{_datadir}/groff/1.23.0/font/devascii
rm -rf %{buildroot}%{_datadir}/groff/1.23.0/font/devlatin1
rm -rf %{buildroot}%{_datadir}/groff/1.23.0/font/devps
rm -rf %{buildroot}%{_datadir}/groff/1.23.0/font/devutf8
rm -rf %{buildroot}%{_datadir}/groff/1.23.0/pic
rm -rf %{buildroot}%{_datadir}/groff/1.23.0/tmac
rm -rf %{buildroot}%{_datadir}/groff/site-tmac
rm -rf %{buildroot}%{_datadir}/groff/site-font
rm -f %{buildroot}%{_mandir}/man1/eqn.1*
rm -f %{buildroot}%{_mandir}/man1/groff.1*
rm -f %{buildroot}%{_mandir}/man1/grog.1*
rm -f %{buildroot}%{_mandir}/man1/grops.1*
rm -f %{buildroot}%{_mandir}/man1/grotty.1*
rm -f %{buildroot}%{_mandir}/man1/mmroff.1*
rm -f %{buildroot}%{_mandir}/man1/neqn.1*
rm -f %{buildroot}%{_mandir}/man1/nroff.1*
rm -f %{buildroot}%{_mandir}/man1/pic.1*
rm -f %{buildroot}%{_mandir}/man1/preconv.1*
rm -f %{buildroot}%{_mandir}/man1/soelim.1*
rm -f %{buildroot}%{_mandir}/man1/tbl.1*
rm -f %{buildroot}%{_mandir}/man1/troff.1*

# Prepare alternatives
find %{buildroot}%{_mandir}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives

## This construct should help identify whether the manpage is compressed,
## and the mv/ln TARGET parameter should be adjusted accordingly.
ext_man="%{?ext_man}%{!?ext_man:.gz}"
manfile="$(find %{buildroot}%{_mandir}/man7/ -type f -name "roff.7${ext_man}")"
test -z "${manfile}" && unset ext_man

mv -v "%{buildroot}%{_mandir}/man7/roff.7${ext_man:-}" \
    "%{buildroot}%{_mandir}/man7/roff-gf.7${ext_man:-}"
ln -s -f "%{_sysconfdir}/alternatives/roff.7${ext_man:-}" \
    "%{buildroot}%{_mandir}/man7/roff.7${ext_man:-}"
# full_build
%else
# fix permission for devps/generate/afmname
# used by ghostscript-fonts-grops
chmod +x %{buildroot}%{_datadir}/groff/%{version}/font/devps/generate/afmname
# install files needed by ghostscript-fonts-grops
install -m 0644 font/devps/generate/symbolsl.awk %{buildroot}%{_datadir}/groff/%{version}/font/devps/generate
install -m 0644 font/devps/generate/zapfdr.sed %{buildroot}%{_datadir}/groff/%{version}/font/devps/generate
install -m 0644 font/devps/generate/freeeuro.sfd %{buildroot}%{_datadir}/groff/%{version}/font/devps/generate
install -m 0644 font/devps/generate/sfdtopfa.pe %{buildroot}%{_datadir}/groff/%{version}/font/devps/generate
install -m 0644 font/devps/symbolsl.ps %{buildroot}%{_datadir}/groff/%{version}/font/devps/
# remove all not really wanted files (they are present in -full variant)
rm -rf %{buildroot}%{_mandir}/man5/
rm -rf %{buildroot}%{_mandir}/man7/
rm -rf %{buildroot}%{_infodir}/

rm -rf %{buildroot}%{_libexecdir}/groff/groffer/
rm -rf %{buildroot}%{_libexecdir}/groff/gpinyin/
rm -rf %{buildroot}%{_libexecdir}/groff/glilypond/
rm -f %{buildroot}%{_libexecdir}/groff/{groff_opts_no_arg.txt,groff_opts_with_arg.txt}

rm -rf %{buildroot}%{_docdir}/groff

rm -rf %{buildroot}%{_datadir}/%{name}/%{version}/font/devcp1047
rm -rf %{buildroot}%{_datadir}/%{name}/%{version}/font/devdvi
rm -rf %{buildroot}%{_datadir}/%{name}/%{version}/font/devhtml
rm -rf %{buildroot}%{_datadir}/%{name}/%{version}/font/devlbp
rm -rf %{buildroot}%{_datadir}/%{name}/%{version}/font/devlj4
rm -rf %{buildroot}%{_datadir}/%{name}/%{version}/font/devpdf
rm -rf %{buildroot}%{_datadir}/%{name}/%{version}/oldfont/

for i in addftinfo afmtodit chem eqn2graph gdiffmk glilypond gperl gpinyin grap2graph grn grodvi groffer grolbp grolj4 gropdf hpftodit indxbib lkbib lookbib pdfmom pdfroff pfbtops pic2graph post-grohtml pre-grohtml refer roff2dvi roff2html roff2pdf roff2ps roff2text roff2x tfmtodit; do
  rm -f %{buildroot}%{_bindir}/$i
  rm -f %{buildroot}%{_mandir}/man1/$i.1*
done
# this man does werdly not have reflecting binary
rm -f %{buildroot}%{_mandir}/man1/grohtml.1*

# compat symlinks
ln -s -f eqn %{buildroot}%{_bindir}/geqn
ln -s -f tbl %{buildroot}%{_bindir}/gtbl

# install profiles to disable the use of ANSI colour sequences by default:
install -d -m 0755 %{buildroot}/%{_sysconfdir}/profile.d
install -m 644 %{SOURCE3} %{SOURCE4} %{buildroot}/%{_sysconfdir}/profile.d/

# full_build
%endif

%fdupes -s %{buildroot}

%if %{with full_build}
%post -n groff-full
%install_info --info-dir=%{_infodir} %{_infodir}/groff.info.gz
if test -f %{_mandir}/man7/roff-gf.7%{?ext_man} ; then
   update-alternatives --install \
      %{_mandir}/man7/roff.7%{?ext_man} roff.7%{?ext_man} \
          %{_mandir}/man7/roff-gf.7%{?ext_man} 500
fi

%preun -n groff-full
%install_info_delete --info-dir=%{_infodir} %{_infodir}/groff.info.gz
if [ $1 -eq 0 ] ; then
   update-alternatives --remove man.7%{?ext_man} %{_mandir}/man7/man-gf.7%{?ext_man}
fi
%endif

%if !%{with full_build}
%files
%license COPYING FDL LICENSES
%doc BUG-REPORT ChangeLog* MANIFEST MORE.STUFF NEWS PROBLEMS PROJECTS README
%{_bindir}/eqn
%{_bindir}/geqn
%{_bindir}/groff
%{_bindir}/grog
%{_bindir}/grops
%{_bindir}/grotty
%{_bindir}/gtbl
%{_bindir}/mmroff
%{_bindir}/neqn
%{_bindir}/nroff
%{_bindir}/pic
%{_bindir}/preconv
%{_bindir}/soelim
%{_bindir}/tbl
%{_bindir}/troff
%{_mandir}/man1/eqn.1%{?ext_man}
%{_mandir}/man1/groff.1%{?ext_man}
%{_mandir}/man1/grog.1%{?ext_man}
%{_mandir}/man1/grops.1%{?ext_man}
%{_mandir}/man1/grotty.1%{?ext_man}
%{_mandir}/man1/mmroff.1%{?ext_man}
%{_mandir}/man1/neqn.1%{?ext_man}
%{_mandir}/man1/nroff.1%{?ext_man}
%{_mandir}/man1/pic.1%{?ext_man}
%{_mandir}/man1/preconv.1%{?ext_man}
%{_mandir}/man1/soelim.1%{?ext_man}
%{_mandir}/man1/tbl.1%{?ext_man}
%{_mandir}/man1/troff.1%{?ext_man}
%config %{_sysconfdir}/profile.d/zzz-%{name}.*sh
%{_datadir}/%{name}
%dir %{_libexecdir}/groff
%{_datadir}/groff/current

%else #groff_base_only

%files -n groff-full
%dir %{_datadir}/groff/%{version}
%dir %{_libexecdir}/groff
%doc %{_docdir}/groff
%dir %{_libexecdir}/groff
%exclude %{_docdir}/groff/html
%exclude %{_docdir}/groff/examples
%exclude %{_docdir}/groff/pdf
%{_infodir}/groff*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man7/*
%exclude %{_mandir}/man1/gxditview.1*
%ghost %{_sysconfdir}/alternatives/roff.7%{?ext_man}
%{_bindir}/*
%exclude %{_bindir}/gxditview
%dir %{_datadir}/groff
%{_datadir}/groff/%{version}/font
%{_datadir}/groff/%{version}/oldfont

%files -n groff-doc
%dir %{_docdir}/groff
%doc %{_docdir}/groff/html
%doc %{_docdir}/groff/examples
%doc %{_docdir}/groff/pdf

%files -n gxditview
%dir %{_datadir}/X11/app-defaults
%doc src/devices/xditview/ChangeLog
%doc src/devices/xditview/README
%doc src/devices/xditview/TODO
%{_bindir}/gxditview
%{_mandir}/man1/gxditview.1%{?ext_man}
%{_datadir}/X11/app-defaults/GXditview
%{_datadir}/X11/app-defaults/GXditview-color

%endif #groff_base_only

%changelog
* Fri Sep 13 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Add groff-restore-hyphen-minus.patch (bsc#1226153)
* Wed Oct  4 2023 Luciano Santos <luc14n0@opensuse.org>
- Define ext_man="%%{?ext_man}%%{!?ext_man:.gz}" shell variable in
  the install directive, and replace "%%{?ext_man}" with
  "${ext_man:-}" to fix groff-gf.7.gz file ending up uncompressed
  (despite the name) due to the use of %%{?ext_man} in the mv/ln
  TARGET parameter used for the preparation of Alternatives. Also
  define a simple shell contruct which identifies whether the
  manpage file is compressed. If not, it unsets the $ext_man
  variable, then ajdusting the mv/ln calls. That's all necessary
  because even though ext_man macro is defined, it doesn't mean the
  file has the extension (which dependes whether the build script
  compresses it).
* Fri Sep  8 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Refresh bash-scripts.patch
- Add nroff-map-CW-to-R.patch
  * Fixes man-db build errors
* Tue Aug 29 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 1.23.0:
  * Too many changes, see NEWS file for details.
- Refreshed patches:
  * 0002-documentation-for-the-locale-keyword.patch
  * 0004-don-t-use-usr-bin-env-in-shebang.patch
  * groff-1.20.1-deunicode.patch
  * groff-1.20.1-nroff-empty-LANGUAGE.patch
  * groff-1.21-CVE-2009-5081.patch
  * groff-force-locale-usage.patch
- Drop sort-perl-hash-keys.patch (upstreamed)
- Drop doc-volume-operating-system and doc-default-operating-system
  changes (doesn't default to BSD anymore)
- Configure flag --with-appresdir has been renamed to --with-appdefdir
- Update file list with files that were removed from the package
* Thu Mar 16 2023 pgajdos@suse.com
- ship %%{_docdir}/groff/pdf also in groff-doc [bsc#1208498]
* Wed Jan  4 2023 pgajdos@suse.com
- set doc-default-operating-system and doc-volume-operating-system
  to SUSE [bsc#1185613c#5], $PRETTY_NAME cannot be used build time
* Thu Dec 15 2022 pgajdos@suse.com
- set doc-default-operating-system and doc-volume-operating-system
  to $PRETTY_NAME [bsc#1185613]
* Mon Feb  7 2022 Stanislav Brabec <sbrabec@suse.com>
- Do not fail with rpm --excludedocs (bsc#1192195).
* Tue Nov 30 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove /usr/share/groff/current from groff-full. It creates file
  conflicts during version upgrade (bsc#1192195#c8).
* Sat Oct 10 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Don't create recursive link 'current' inside
  /usr/share/groff/%%{version}.
* Thu Jan  9 2020 Ludwig Nussel <lnussel@suse.de>
- don't recommend groff-full as that would pull in X etc by default.
  Instead use packageand on groff and ghostscript-library to only install
  groff-full when other deps are already there.
* Mon Dec 16 2019 Matej Cepl <mcepl@suse.com>
- Add man page roff(7) to alternatives to avoid conflict with
  mandoc.
* Mon Feb 18 2019 Marguerite Su <i@marguerite.su>
- install essential build files needed by ghostscript-fonts-grops
* Sat Jan 12 2019 Jan Engelhardt <jengelh@inai.de>
- Trim tm signs
* Fri Jan  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 1.22.4:
  * Many fixes for hyphenation helping
  * Various build tweaks
  * See the NEWS file for details
- New signature -> update keyring file
- Remove upstream merged patches:
  * groff-multi-thread.patch
  * groff-reproducible-mdate.patch
  * groff-use-SDE.patch
- Remove groff-1.21-groffer-libexecdir.patch as upstream redid
  the autotools rules and uses configure option now
- Rebase patch groff-1.20.1-deunicode.patch
- Rebase patch groff-1.21-CVE-2009-5081.patch
- Drop patch groff-1.21-CVE-2009-5080.patch as it seems the shell
  script now properly safeguards against this
- Rebase patch 0002-documentation-for-the-locale-keyword.patch
- Recreate groff-force-locale-usage.patch for autotools buildsystem
- Add patch 0004-don-t-use-usr-bin-env-in-shebang.patch
- Remove groff_1.22.3-1.debian.diff and replace it with split
  debian patches:
  * bash-scripts.patch
  * sort-perl-hash-keys.patch
* Thu Jan  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild in order to avoid having to manage 2
  differentiating spec files
* Tue Oct 30 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- add groff-reproducible-mdate.patch and groff-use-SDE.patch to allow
  to override build time to make package build reproducible (boo#1047218)
* Mon Mar 19 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Mon Dec 18 2017 tchvatal@suse.com
- Set the license to GPL-3.0+ as per COPYING
* Thu Dec 14 2017 crrodriguez@opensuse.org
- Replace xorg-x11-devel buildrequires by the needed individual
  libraries
* Thu Jul 21 2016 tchvatal@suse.com
- Add patch for bnc#989903 and move all scripts from libdir to
  libexecdir
* Wed Feb  4 2015 tchvatal@suse.com
- Version bump to latest release 1.22.3:
  * X11 resources for `gxditview', which were previously installed in
    /usr/X11/lib/X11/app-defaults no matter which `prefix' was set, are
    now installed in appresdir=$prefix/lib/X11/app-defaults.  If
    `appresdir' is not a standard X11 resource directory, the environment
    variable XFILESEARCHPATH should be set to this path.  The standard
    default directories depends on the system `libXt'.
  * This new preprocessor (contributed by Bernd Warken) allows embedding of
    code for GNU LilyPond (http://www.lilypond.org), a music typesetter.  The
    data gets automatically processed and embedded as EPS images.
  * Bernd Warken contributed a new preprocessor to handle Perl code that can
    be evaluated and then processed by groff.
  * Another preprocessor from Bernd Warken to pretty-print Pinyin syllables
    like `guo2wang2' as `guówáng'.
  * The pdfroff utility script now activates its `--no-toc-relocation' option
    by default, unless a request similar to:
    .if !\n[PHASE] .tm pdfroff-option:set toc_relocation=enabled
    is invoked during input file processing; (`.if !\n[PHASE] ...' ensures
    that the effect of the `.tm' request is restricted to the document setup
    phase of processing, as pdfroff sets it to 1 or 2 in the output phase,
    but leaves it unset in the setup phase).
    The bundled `spdf.tmac' macro package, which implicitly activates
    `-mpdfmark' for `ms' macro users, ensures that TOC relocation is
    appropriately enabled, when the `.TC' macro is invoked.
  * The -mom macro package now has full support for eqn, pic, and tbl, as well
    as captioning and labelling of pdf images and preprocessor output.  Lists
    of Figures, Equations, and Tables can now be autogenerated.  PDF_IMAGE has
    a new FRAME option.
  * A French introduction to the -me macro package has been added (file
    `meintro_fr.me').
  * In -mdoc, command %%C is now available, providing a city or place
    reference.
- Refreshed patches:
  * groff-1.21-CVE-2009-5081.patch
  * groff-1.21-groffer-libexecdir.patch
  * groff-force-locale-usage.patch
- Replaced patches:
  * deleted groff_1.22.2-2.debian.diff
  * added groff_1.22.3-1.debian.diff
- New patches:
  * groff-multi-thread.patch
* Sat Dec 20 2014 meissner@suse.com
- build with PIE
* Tue Jun 25 2013 mvyskocil@suse.com
- move man.local and mdoc.local from groff-full to groff
  * fixes libssh2.org testsuite
* Mon Jun 17 2013 werner@suse.de
- Take care of mmroff.1.gz as well as of mmroff perl script
* Mon Jun 17 2013 werner@suse.de
- Move important non-graphical macros from groff-full back to groff
  as otherwise many packages do not build anymore
* Wed Jun  5 2013 mvyskocil@suse.com
- modify groff_1.22.2-2.debian.diff - remove the part related to
  src/preproc/html/pre-html.cpp, fixes bnc#755533
* Thu May  9 2013 mvyskocil@suse.com
- update to groff 1.22.2
  * gropdf: A new driver for generating PDF output directly,
    contributed by Deri James and written in Perl
  * The -mom macro package has reached version 2.0, focusing on
    PDF output with gropdf (using the new `pdfmom' wrapper script).
    See the file`version-2.html' of the -mom documentation for a list
    of the many changes.
  * pdfmom: A new wrapper around groff that facilitates the production of PDF
    documents from files formatted with the -mom macros.
  * and a lot more, see NEWS for details
- obsoletes:
    config-guess-sub-update.patch, dtto
    groff_1.21-6.debian.diff, replaced by
- added groff_1.22.2-2.debian.diff
- create a stripped-down version of groff usable for viewing of manual pages
- new groff-full package contains the rest of groff tools capable to work with
  images, html or pdf. It contains the devx fonts, thus obsoletes groff-devx
  it aims to fix bnc#755533 - grohtml built without pnm* tools in PATH
- gxdview.spec is removed as gxdview is built from groff-full.spec
- verify the tarball using gpg-offline - this is done in groff-full only
  to retain a limited list of dependencies for base groff
- Remove not really needed patch groff-1.20.1-destbufferoverflow.patch
* Tue May  7 2013 schwab@suse.de
- config-guess-sub-update.patch: Update config.guess/sub for aarch64
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Fri Sep  7 2012 coolo@suse.com
- add explicit buildrequire makeinfo
* Sun Mar 18 2012 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Enable parallel build with %%_smp_mflags
* Thu Sep 29 2011 adrian@suse.de
- use RPM_OPT_FLAGS for compile
* Thu Sep 29 2011 mvyskocil@suse.cz
- implemented FATE#312586 - Add locales support for groff papersize
  * the default papersize is now determined from system locale (LC_PAPER)
  * /etc/papersize is no longer owned by the groff package
* Thu Sep 22 2011 mvyskocil@suse.cz
- fix bnc#703665 - VUL-1: groff: missing checks for mktemp failures
  (CVE-2009-5080)
- fix bnc#703666 - VUL-1: groff: insufficient number of X for mktemp
  (CVE-2009-5081)
* Mon Jun 27 2011 mvyskocil@suse.cz
- update to 1.21 a bugfix release
  * use new groff_1.21-6.debian.diff
  * refresh libexecdir and pdfroff patch
- fix FATE#311297: Get rid of SuSEconfig.groff
  * removed
* Wed Jun  8 2011 mvyskocil@suse.cz
- fix bnc#698290: insecure temporary file handling in pdfroff
  * groff-1.20.1-CVE-2009-5044.patch
- fix bnc#683857: Unicode characters in use properly
  * change the soft hyphenation char to - in tty.tmac
* Mon Jun  6 2011 mvyskocil@suse.cz
-
- fix bnc#682913: device X100 is missing
  * create new groff-devx package containing all devX devices, as they
    need X for build
- fix bnc#683857: Unicode characters in use
  * groff-1.20.1-deunicode.patch adds deunicode.tmac to tty.tmac removes
    all unecessary unicode characters in tty output
* Tue Mar 15 2011 mvyskocil@suse.cz
- fix bnc#679585 - groff.info is not installed
  * install info files as %%{name}.info.gz
* Thu Oct  7 2010 mvyskocil@suse.cz
- fix bnc#644467: SuSEconfig.groff overwrites /etc/papersize
  use the check_md5_and_move to prevent it
- deprecation warning for  GROFF* variables in /etc/sysconfig/suseconfig
* Tue Oct  5 2010 mvyskocil@suse.cz
- fix bnc#633128: Update groff to 1.20.1
  this update obsoletes a big number of SUSE patches
  * groff_1.18.1.1-1-debian.diff.bz2 - adds Japanese support, which is now
    upstreamed. However new groff_1.20.1-10.debian.diff has been added
  * suse.patch - not needed
  * pic-html.patch - probably not needed
  * gcc4.patch - already fixed by upstream
  * groff-1.17.2-gcc3.patch - seems not needed
  * utf8.patch - http://www.mail-archive.com/groff@gnu.org/msg05273.html says
    iconv hack is no longer needed, new version uses preconv
  * debian-fix.patch - already fixed by upstream
  * double-free.patch - already fixed by upstream
  * groffer-security.patch - in debian diff
  * groff-1.18.1.1-gcc41.patch - already fixed by upstream
  * bugzilla-217106-too-few-arguments-in-function-call.patch - makes sense
    only with ENABLE_MULTIBYTE, which was added by old debian diff
  * bugzilla-292412-special-encoding-handling-also-for-chinese.patch - seems not necessary
  * gcc43.patch - already fixed by upstream
  * fgets-overflow.patch - already fixed by upstream
  * bnc446710.patch - seems not needed anymore
  * groff-1.18.1.1-debian-538330.patch - part of debian diff
- fix bnc#643083 - groff: default /etc/papersize should be "a4"
  no "papersize a4" without SuSEconfig anymore
- move docs and examples to groff-docs subpackage
* Wed Oct 14 2009 mvyskocil@suse.cz
- fixed bnc#529557 - groff: insecure file handling
* Mon Sep 21 2009 tiwai@suse.de
- fix broken output of man page when $LANGUAGE is set empty
  (bnc#540600)
* Mon Feb  2 2009 mfabian@suse.de
- bnc#470921: add more workarounds for Korean to fix the truncation
  of some non-Korean man-pages in ko_KR.UTF-8 locale.
* Mon Dec 22 2008 mls@suse.de
- keep zzz-groff.csh from aborting if LANG is unset
* Tue Nov 25 2008 mfabian@suse.de
- bnc#448185: improve workaround for bnc#446710. After the
  tmandocdb workaround was removed from "man", the new
  workaround in groff failed in some locales.
* Fri Nov 21 2008 mfabian@suse.de
- bnc#401952: Add a workaround to /usr/bin/nroff to make Korean
  man-pages display correctly again.
- /etc/profile.d/groff.{sh,csh} moved to
  /etc/profile.d/zzz-groff.{sh,csh} to be able to check for LANG.
  Changes in these scripts:
  • Don’t set GROFF_NO_SGR by default anymore, it causes problems
    with Korean man pages.
  • For CJK languages, set MAN_KEEP_FORMATTING by default.
    Without MAN_KEEP_FORMATTING man will use GROFF_NO_SGR when
    writing to a pipe or file and will also pipe the result
    through "col -b -p -x". This doesn’t work well for CJK, at
    least not with the current version of groff.
* Thu Nov 20 2008 mfabian@suse.de
- bnc#446710: add the workarounds from
  /usr/share/groff/site-tmac/tmac.andocdb (man package) directly
  to groff. These workarounds are to avoid rendering - as
  U+2010 (HYPHEN), \- as U+2212 (MINUS SIGN), ` as U+2018
  (LEFT SINGLE QUOTATION MARK), and ' as U+2019 (RIGHT SINGLE
  QUOTATION MARK). Using these non-ASCII characters for rendering
  man-pages with programm examples and command line options is
  confusing and prevents cut and paste of code examples
  impossible.
* Wed Oct  8 2008 crrodriguez@suse.de
- fix buffer overflow in ps.cc
* Mon Oct  6 2008 meissner@suse.de
- fixed fgets overflow
- fixed some rpmlint issues
* Mon Apr 21 2008 mfabian@suse.de
- bnc#381905: remove the hack in /usr/bin/nroff to convert
  UTF-8 encoded man-pages back to the appropriate legacy encoding
  because newer versions of “man” also do this conversion now
  and doing the same conversion twice breaks it.
* Tue Mar 25 2008 mfabian@suse.de
- bnc#373284: fix wrong spelling of UTF-8 in iconv call used in
  nroff.sh (Thanks to Bruno Haible <bruno@clisp.org> for the fix).
* Wed Nov  7 2007 meissner@suse.de
- fixed gcc4.3 build
* Tue Jul 24 2007 mfabian@suse.de
- Bugzilla #292412: make the hacks for Chinese less weird by
  applying the patch from comment #31 by Peng Wu <pwu@novell.com>
  and adapting the patch to /usr/bin/nroff.
- remove shebang from SuSEconfig.groff (is sourced, not executed).
* Mon Jul 23 2007 mfabian@suse.de
- Bugzilla #292412: add some more hacks to /usr/bin/nroff to
  support Chinese man pages as well.
* Mon Mar 26 2007 rguenther@suse.de
- add bison BuildRequires.
* Wed Jan 17 2007 mfabian@suse.de
- Bugzilla #217106: too few arguments in function call.
* Tue Jan  9 2007 mfabian@suse.de
- do not build as root.
- make it build in the openSUSE build service.
* Tue Jan  2 2007 mfabian@suse.de
- Bugzilla #230030: make Russian and Czech man-pages display
  correctly again in UTF-8 locales (has been broken by the
  update to man-2.4.3).
* Tue Sep  5 2006 rguenther@suse.de
- Split gxdview to a separate spec file.
* Mon Sep  4 2006 rguenther@suse.de
- Remove unneeded build dependency on ghostscript-mini.
* Sun Aug  6 2006 cthiel@suse.de
- fix build with X.org 7.1
* Tue Feb 28 2006 mfabian@suse.de
- Bugzilla #148472: use -Tlatin1 instead of -Tascii8 for
  languages which used ISO-8859-1 as legacy encoding.
  With -Tascii8, "\(:u" for ü won't work.
* Thu Feb  9 2006 mfabian@suse.de
- Bugzilla #148922: nroff hangs when input comes from a file
  and not from a pipe: Improfe UTF-8 workaround to handle this
  case as well by parsing the options with getopt to find out
  whether a file was given as an argument.
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Mon Jan 23 2006 mfabian@suse.de
- Bugzilla #144726: add workaround to allow UTF-8 encoded sources
  of man-pages. Some packages already contain man-pages with
  UTF-8 encoded man-page sources, for example "mc". Hopefully
  one day groff will really support this. Until then a workaround
  is better than nothing.
* Fri Dec  9 2005 meissner@suse.de
- -fno-strict-aliasing.
* Thu Oct 13 2005 meissner@suse.de
- fixed build.
* Sat Sep 17 2005 meissner@suse.de
- fixed implicits.
* Mon Aug 22 2005 mfabian@suse.de
- Bugzilla #105807: /etc/papersize can be changed by SuSEconfig,
  don't verify md5, size, mtime.
  /usr/share/groff/1.18.1/tmac/mm/locale and
  /usr/share/groff/1.18.1/tmac/mm/se_locale are empty by default,
  don't verify md5.
* Wed Jun 22 2005 mfabian@suse.de
- improve papersize detection in SuSEconfig.groff.
* Thu Jun  2 2005 mfabian@suse.de
- add symbolic link for tetex (and others):
  /usr/share/groff/%%{version} -> /usr/share/groff/current
* Mon Dec  6 2004 mfabian@suse.de
- Bugzilla #47862: fix insecure creation of temporary directory
  in groffer.sh, see also CAN-2004-0969.
* Fri Sep 17 2004 mfabian@suse.de
- add gcc4 patch received from Andreas Jaeger.
* Thu Sep 16 2004 schwab@suse.de
- Fix double free.
* Tue Sep  7 2004 mfabian@suse.de
- Bugzilla #44115: add groff.{sh,csh} and set GROFF_NO_SGR to
  disable the use of ANSI colour sequences by default. They don't
  work well with many pagers (e.g. lv, (X)Emacs) and they cause
  problems when searching in man-pages when using less as the
  pager.
* Tue Jun 29 2004 mfabian@suse.de
- update to 1.18.1.1
- remove bison patch, voiddecl patch and patch to node.cc
  (fixed upstream).
* Mon Apr 19 2004 mmj@suse.de
- Declare void functions as such, and make int functions return such
* Mon Aug 25 2003 mfabian@suse.de
- Bugzilla #28394: add workaround to display the euro symbol in
  'man iso-8859-15' correctly in UTF-8 locales.
* Thu Aug 14 2003 mfabian@suse.de
- Bugzilla #28945: add missing activation metadata to
  sysconfig template
* Wed May 21 2003 coolo@suse.de
- making /etc/papersize noreplace (the chances are very small the
  package knows the papersize better than the user)
- installing the info pages
* Thu Mar  6 2003 ro@suse.de
- readd ghostscript-mini to neededforbuild (fix docu)
* Thu Mar  6 2003 mfabian@suse.de
-  Bug #24758: fix segfault on copying an empty bracket_node
  was reproducible with    echo ' \b"" ' | troff
* Mon Jan 27 2003 mfabian@suse.de
- Bug #22693: add missing metadata to sysconfig.suseconfig-groff
* Mon Jan 20 2003 mfabian@suse.de
- fix file list to include /usr/share/man{5,7}/*
- extend workaround for non-latin1 man-page sources in UTF-8
  locales to Hungarian, Croatian, Polish, and Russian
* Fri Dec  6 2002 olh@suse.de
- remove ghostscript-mini-packages to build groff anyway
* Wed Nov 20 2002 ro@suse.de
- use ghostscript-mini-packages
* Wed Nov 13 2002 ro@suse.de
- fix build with current bison (end all rules with ";")
* Sun Oct 13 2002 mfabian@suse.de
- remove bogus "Requires:     bc".
* Wed Aug 28 2002 mfabian@suse.de
- fix display of Czech man pages in cs_CZ.UTF-8 locale
* Thu Aug  1 2002 mfabian@suse.de
- add %%fillup_prereq to Prereq:
* Tue Jun  4 2002 mfabian@suse.de
- fix typo
* Tue Jun  4 2002 mfabian@suse.de
- fix display of Japanese man pages in ja_JP.UTF-8 locale
* Thu May  2 2002 meissner@suse.de
- Fixed g++ 3 issue (do not link C++ libraries with gcc)
* Sun Apr  7 2002 schwab@suse.de
- Fix for new autoconf.
* Mon Mar 18 2002 mfabian@suse.de
- fix bug #15052: add 'libgimpprint glib glib-devel' to
  '# neededforbuild' because 'gs' needs this to run. When 'gs'
  doesn't run, some .png pictures in the 'doc' directory
  can't be created and remain empty.
- add groff-1.17.2-pic-html.diff to avoid using the process ID
  in the names of the created .png files.
* Sun Mar 10 2002 mfabian@suse.de
- write just 'a4' or 'letter' into /etc/papersize, not
  'papersize a4' or 'papersize letter'. All this papersize
  stuff doesn't seem to matter much anyway as groff calls
  grops with the '-g' option (guess page length).
* Sat Mar  9 2002 ro@suse.de
- replaced plp by lprng in neededforbuild
* Fri Mar  1 2002 mfabian@suse.de
- fix /sbin/conf.d/SuSEconfig.groff:
  prefer paper size information from the locale, use GROFF_PAGESIZE
  as an override.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Jan 16 2002 ro@suse.de
- moved variables to sysconfig/suseconfig
* Thu Jan 10 2002 mfabian@suse.de
- move *GROFF* variables from /etc/rc.config to
  /etc/sysconfig/groff (fix Bug #12739)
* Mon Oct 15 2001 mfabian@suse.de
- add /etc/papersize (fix Bug #11810)
* Mon Sep  3 2001 mfabian@suse.de
- add obsoletes jgroff
* Thu Aug 30 2001 mfabian@suse.de
- upgrade debian patch to groff_1.17.2-7.diff
  (fixes the problem with bold utf-8 characters, i.e. obsoletes
  groff_1.17.2-6.1-debian-fix-minus.diff and includes a fix
  for the troff man-page)
* Tue Aug 21 2001 mfabian@suse.de
- upgrade debian patch to groff_1.17.2-6.1.diff
  (fix hyphen character problem in EUC-JP encoding,
  Fumitoshi UKAI <ukai@debian.or.jp>  Fri, 17 Aug 2001)
- fix problem with bold minus characters in utf-8 caused by
  debian patch (thanks to <mls@suse.de>)
* Fri Aug 17 2001 mfabian@suse.de
- include patch for Japanese support from Debian
- security fix from Sebastian Krahmer <krahmer@suse.de> seems
  to be included upstream, removed.
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_fonts> to <ghostscript-fonts-std>
- changed neededforbuild <gs_lib> to <ghostscript-library>
- changed neededforbuild <gs_serv> to <ghostscript-serv>
* Thu Jul 12 2001 fehr@suse.de
- update to version 1.17.2
* Fri Jul  6 2001 fehr@suse.de
- add security fix from Sebastian Krahmer <krahmer@suse.de>
* Mon Jun 25 2001 fehr@suse.de
- update to version 1.17.1
* Tue Jun 12 2001 fehr@suse.de
- make it build with newer compilers (ia64, axp)
* Tue May 22 2001 fehr@suse.de
- update to version 1.17
* Mon May  7 2001 mfabian@suse.de
- bzip2 source
* Sat Apr 21 2001 schwab@suse.de
- Fix C++ constraint violation.
* Wed Mar  7 2001 uli@suse.de
- added xf86 to neededforbuild
* Wed Dec 13 2000 mfabian@suse.de
- added "Provides: normal-groff". This enables the japanized
  groff to use "Provides: groff" and "Conflicts: normal-groff".
* Fri Dec  8 2000 fehr@suse.de
- add conflicts to jgroff
* Tue Sep  5 2000 fehr@suse.de
- check for writable fontdir in SuSEconfig.groff (#2787)
* Tue Aug 15 2000 mfabian@suse.de
- update to version 1.16.1
- added 'BuildRoot'
* Fri Aug  4 2000 fehr@suse.de
- changes to new version 1.16.1 of groff
* Fri Jul 21 2000 fehr@suse.de
- add patch to display japanese man pages again
* Fri Jul  7 2000 fehr@suse.de
- change comment in rc.config part of package (bugzilla #3256)
* Mon May 29 2000 fehr@suse.de
- changes to new version 1.16 of groff
* Fri May 19 2000 fehr@suse.de
- move documentation to /usr/share/doc/packages
* Thu Mar 16 2000 werner@suse.de
- nroff script
  * Allow other ISO latin character sets because they use the same
    8 bit table: use -Tlatin1
  * Allow wide ANSI character maps (e.g. Japanese) because they use
    multiple 8 bit characters: use -Tlatin1
  * Map -Tnippon to -Tlatin1
* Mon Mar  6 2000 schwab@suse.de
- Update tmac.m from CVS.
- Fix tmac.mse reference to tmac.m.
* Fri Feb 25 2000 schwab@suse.de
- /usr/man -> /usr/share/man
* Mon Jan  3 2000 schwab@suse.de
- Update to 1.15 (Y2K fix).
- Get rid of Makefile.Linux.
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jul  2 1999 werner@suse.de
- Fix Makefle.Linux to make (g)xditview with the values
  set in Imakefile
- Split up a new package gxdview to avoid dependencies
  of groff on the X11 system.
- Correct version number of groff in pac
* Tue Feb 23 1999 ro@suse.de
- don't redclare strchr for glibc
* Mon Dec 14 1998 bs@suse.de
- fixed SuSEconfig
* Sun Dec 13 1998 bs@suse.de
- made SuSEconfig.groff a little bit more silent.
* Wed Nov 18 1998 ro@suse.de
- commented out "find" in specfile
* Tue Nov 17 1998 werner@suse.de
- Remove hint during SuSEconfig.groff
* Thu Sep  3 1998 werner@suse.de
- Add three missed files
* Tue Aug 25 1998 werner@suse.de
- Skipt warn message if printer isn't configured
* Thu Aug  6 1998 werner@suse.de
- New version 1.11a
- Make docs and install them
- Add a auto configure script for SuSEconfig
- Make tmac/tmac.safer more safer: do not open files via .so
* Sun Jul 26 1998 bs@suse.de
- fixed name of GXDITVIEW
* Tue Oct  7 1997 florian@suse.de
- prepared spec file
- "bash 2.0" Fix in Makefile
